.. image:: https://travis-ci.org/timcera/astronomia.svg?branch=master
    :target: https://travis-ci.org/timcera/astronomia
    :height: 20

.. image:: https://coveralls.io/repos/timcera/astronomia/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/astronomia?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/astronomia.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/astronomia

.. image:: http://img.shields.io/badge/license-GPL-lightgrey.svg
    :alt: GPL license
    :target: https://pypi.python.org/pypi/astronomia
.. image:: http://img.shields.io/pypi/dd/astronomia.svg
    :alt: astronomia downloads
    :target: https://pypi.python.org/pypi/astronomia/
